Crate tagged_vec

Crate tagged_vec 

An alternative to the standard libraries’ Vec which is indexed with a custom type instead of usize.

This is useful to catch errors like using the wrong variable to index the vector.

Structs

IndexIterator
An iterator over the indices of a TaggedVec.
TaggedVec
A Vec wrapper that allows indexing only via the given Index type.